@@ -19,6 +19,7 @@ class DataType(IntEnum):
     PAGE_VIEW_VISIT = 10
     VISITOR_VISITS = 11
     KCS_HEAT = 12
+    UNIQUE_IDENTIFIER = 13
 
 
 class BaseData:
@@ -31,7 +32,7 @@ class BaseData:
 
     def to_dict(self) -> Dict[str, Any]:
         """Convert class instance to dict"""
-        return self.__dict__
+        return {k: str(v) for k, v in self.__dict__.items()}
 
 
 class Data(BaseData):  # pylint: disable=W0223
