@@ -174,7 +174,12 @@ class Visitor:
     @mapping_identifier.setter
     def mapping_identifier(self, value: str):
         """Sets the mapping identifier for this Visitor."""
-        self._data.mapping_identifier = value
+        if self._data.mapping_identifier:
+            return
+        with self._data.lock:
+            if self._data.mapping_identifier:
+                return
+            self._data.mapping_identifier = value
         KameleoonLogger.debug("CALL/RETURN: Visitor.mapping_identifier <- (mapping_identifier: %s)", value)
 
     @property
