@@ -1,8 +1,6 @@
 """Remote data"""
 from typing import Optional, Any, List
-from kameleoon.configuration.custom_data_info import CustomDataInfo
 from kameleoon.data import Data
-from kameleoon.data.data import BaseData
 from kameleoon.data.manager.visitor_manager import VisitorManager
 from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.managers.data.data_manager import DataManager
@@ -53,33 +51,35 @@ class RemoteDataManager:
             data_filter = RemoteVisitorDataFilter()
         service: DataService = self._network_manager.get_service(DataService)
         response = await service.get_remote_visitor_data(visitor_code, data_filter, is_unique_identifier, timeout)
-        visitor_data = self.__handle_remote_visitor_data_response(response, visitor_code, add_data)
+        visitor_data = self.__handle_remote_visitor_data_response(response, visitor_code, add_data, data_filter)
         KameleoonLogger.debug(
             "CALL: RemoteDataManager.get_visitor_data(visitor_code: %s, add_data: %s, data_filter: %s, timeout: %s) "
             "-> (visitor_data: %s)", visitor_code, add_data, data_filter, timeout, visitor_data)
         return visitor_data
 
     def __handle_remote_visitor_data_response(
-        self, response: Response, visitor_code: str, add_data: bool
+        self, response: Response, visitor_code: str, add_data: bool, data_filter: RemoteVisitorDataFilter
     ) -> List[Data]:
         if response.content is None:
             return []
         custom_data_info = self._data_manager.data_file.custom_data_info
-        data_to_add, data_to_return = RemoteDataManager.__parse_remote_visitor_data(custom_data_info, response.content)
+        remote_visitor_data = RemoteDataManager.__parse_remote_visitor_data(response.content)
+        remote_visitor_data.mark_data_as_sent(custom_data_info)
+        data_to_add = remote_visitor_data.collect_data_to_add()
         if add_data and data_to_add:
             # Cannot use `VisitorManager.add_data` because it could use remote visitor data for mapping.
             visitor = self._visitor_manager.get_or_create_visitor(visitor_code)
             visitor.add_data(*data_to_add, overwrite=False)
-        return data_to_return
+        if data_filter.visitor_code and remote_visitor_data.visitor_code:
+            # We apply visitor code from the latest visit fetched from Data API
+            visitor = self._visitor_manager.get_or_create_visitor(visitor_code)
+            visitor.mapping_identifier = remote_visitor_data.visitor_code
+        return remote_visitor_data.collect_data_to_return()
 
     @staticmethod
-    def __parse_remote_visitor_data(
-            custom_data_info: CustomDataInfo, raw: Any
-    ) -> tuple[List[BaseData], List[Data]]:
+    def __parse_remote_visitor_data(raw: Any) -> RemoteVisitorData:
         try:
-            remote_visitor_data = RemoteVisitorData(raw)
-            remote_visitor_data.mark_data_as_sent(custom_data_info)
-            return remote_visitor_data.collect_data_to_add(), remote_visitor_data.collect_data_to_return()
+            return RemoteVisitorData(raw)
         except Exception as ex:  # pylint: disable=W0703
             KameleoonLogger.error("Parsing of remote visitor data failed: %s", ex)
-            return [], []
+            return RemoteVisitorData({})
