@@ -1,5 +1,5 @@
 """Targeting condition factory"""
-
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.targeting.conditions.browser_condition import BrowserCondition
 from kameleoon.targeting.conditions.conversion_condition import ConversionCondition
 from kameleoon.targeting.conditions.device_condition import DeviceCondition
@@ -102,5 +102,5 @@ class TreeConditionFactory:
 
             return UnknownCondition(condition_json)
         except KeyError as exception:
-            print(f"Unsupported targeted condition type found: {exception}")
+            KameleoonLogger.error("Unsupported targeted condition type found: %s", exception)
             return UnknownCondition(condition_json)
